import React, { useReducer } from 'react';
import { Platform, Modal, View, ActivityIndicator, Text, TouchableNativeFeedback, TouchableOpacity } from 'react-native';
import ModalContext from '../context';
import { actions, reducer, initialState } from './../reducer';
import styles from './styles';
const ModalProvider = props => {
  const {
    animation,
    style,
    activityIndicatorSize = 'large',
    activityIndicatorColor = '#61849B',
    children
  } = props;
  const [state, dispatch] = useReducer(reducer, initialState);
  const {
    preloader,
    dialog
  } = state;
  const determineHeader = () => {
    if ( /*#__PURE__*/React.isValidElement(dialog.header)) {
      return dialog.header;
    } else {
      return /*#__PURE__*/React.createElement(Text, {
        style: [styles.headerText, style === null || style === void 0 ? void 0 : style.dialogHeader]
      }, dialog.header);
    }
  };
  const determineBody = () => {
    if ( /*#__PURE__*/React.isValidElement(dialog.body)) {
      return dialog.body;
    } else {
      return /*#__PURE__*/React.createElement(Text, {
        style: [styles.bodyText, style === null || style === void 0 ? void 0 : style.dialogBody]
      }, dialog.body);
    }
  };
  const actionButton = (text, style, action) => {
    if (Platform.OS === 'android') {
      return /*#__PURE__*/React.createElement(TouchableNativeFeedback, {
        onPress: action
      }, /*#__PURE__*/React.createElement(View, {
        style: style
      }, /*#__PURE__*/React.createElement(Text, {
        style: [styles.buttonText, style === null || style === void 0 ? void 0 : style.dialogAction]
      }, text)));
    } else {
      return /*#__PURE__*/React.createElement(TouchableOpacity, {
        style: style,
        onPress: action
      }, /*#__PURE__*/React.createElement(Text, {
        style: [styles.buttonText, style === null || style === void 0 ? void 0 : style.dialogAction]
      }, text));
    }
  };
  return /*#__PURE__*/React.createElement(ModalContext.Provider, {
    value: {
      state,
      dispatch
    }
  }, /*#__PURE__*/React.createElement(Modal, {
    transparent: true,
    animationType: animation ? animation : 'fade',
    visible: preloader.show || dialog.show
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.modalBackground, style === null || style === void 0 ? void 0 : style.modalContainer]
  }, preloader.show && /*#__PURE__*/React.createElement(View, {
    style: [styles.activityIndicatorWrapper, style === null || style === void 0 ? void 0 : style.activityIndicatorContainer]
  }, /*#__PURE__*/React.createElement(ActivityIndicator, {
    size: activityIndicatorSize,
    color: activityIndicatorColor
  }), preloader.message && /*#__PURE__*/React.createElement(Text, {
    style: [styles.message, style === null || style === void 0 ? void 0 : style.text]
  }, preloader.message)), dialog.show && /*#__PURE__*/React.createElement(View, {
    style: [styles.dialogWrapper, style === null || style === void 0 ? void 0 : style.dialogContainer]
  }, dialog.header && /*#__PURE__*/React.createElement(View, {
    style: styles.headerRow
  }, determineHeader()), /*#__PURE__*/React.createElement(View, {
    style: styles.bodyRow
  }, determineBody()), /*#__PURE__*/React.createElement(View, {
    style: styles.footerRow
  }, dialog.negativeText && actionButton(dialog.negativeText, styles.footerButton, () => dispatch({
    type: actions.dialog.CLOSE,
    payload: 'NEGATIVE'
  })), actionButton(dialog.positiveText, [styles.footerButton, dialog.negativeText ? styles.buttonBorder : null], () => dispatch({
    type: actions.dialog.CLOSE,
    payload: 'POSITIVE'
  })))))), children);
};
export default ModalProvider;
//# sourceMappingURL=index.js.map